@@ -625,24 +625,7 @@ Nsymbols will find the proper symbol, unless duplicate."
     (mapcar (alex:rcurry #'resolve-user-symbol :mode (list-all-packages))
             (remove-duplicates (call-next-method)
                                ;; Modes at the beginning of the list have higher priority.
-                               :from-end t)))
-  (:method append ((buffer context-buffer))
-    (list
-     ;; TODO: No need for `sym:resolve-symbol' if we move `context-buffer'
-     ;; declaration in a separate file, loaded after modes.
-     (sym:resolve-symbol :annotate-mode :mode)
-     (sym:resolve-symbol :bookmark-mode :mode)
-     (sym:resolve-symbol :history-mode :mode)
-     (sym:resolve-symbol :password-mode :mode)))
-  (:method append ((buffer document-buffer))
-    (list
-     ;; TODO: No need for `sym:resolve-symbol' if we move `document-buffer'
-     ;; declaration in a separate file, loaded after modes.
-     (sym:resolve-symbol :hint-mode :mode)
-     (sym:resolve-symbol :document-mode :mode)
-     (sym:resolve-symbol :search-buffer-mode :mode)
-     (sym:resolve-symbol :autofill-mode :mode) ; TODO: Remove from default?
-     (sym:resolve-symbol :spell-check-mode :mode))))
+                               :from-end t))))
 
 (define-class network-buffer (buffer)
   ((status
@@ -880,7 +863,7 @@ Also see `panel-page'."))
    (glyph-lambda (gethash "lambda.svg" *static-data*))
    (style (theme:themed-css (theme *browser*)
             `(body
-              :line-height "24px"
+              :line-height "100vh"
               :font-size "14px"
               :padding 0
               :margin 0)
@@ -911,20 +894,20 @@ Also see `panel-page'."))
             `("#controls"
               :background-color ,theme:secondary
               :color ,theme:on-secondary
-              :padding-left "8px"
               :overflow "hidden"
               :white-space "nowrap"
               :z-index "3"
-              :height "24px"
-              :flex-basis "80px")
+              :flex-basis "80px"
+              :display "flex")
             `("#controls > button"
-              :width "22px"
-              :margin-left "-8px")
-            `("#reload"
-              :width "24px !important")
+              :margin-right "-3px"
+              :max-width "20px"
+              :height "100%"
+              :aspect-ratio "1/1")
             `("#url"
               :background-color ,theme:primary
               :color ,theme:on-primary
+              :font-size "60vh"
               :min-width "100px"
               :text-overflow "ellipsis"
               :overflow-x "hidden"
@@ -941,7 +924,8 @@ Also see `panel-page'."))
             `("#tabs"
               :background-color ,theme:secondary
               :color ,theme:on-secondary
-              :line-height "22px"
+              :line-height "95vh"
+              :font-size "60vh"
               :min-width "100px"
               :white-space "nowrap"
               :overflow-x "scroll"
@@ -972,6 +956,7 @@ Also see `panel-page'."))
             `("#modes"
               :background-color ,theme:primary
               :color ,theme:on-primary
+              :font-size "60vh"
               :text-align "right"
               :padding-left "10px"
               :padding-right "5px"
