@@ -923,3 +923,19 @@ Nyxt version exists.  It is only raised when the major version differs.")
     (:ul
      (:li "When running Nyxt as a Flatpak, programs available on the host can be
 invoked via " (:code "flatpak-spawn --host <command> <command-args>") "."))))
+
+(define-version "3.10.0"
+  (:nsection :title "UI/UX"
+    (:ul
+     (:li "Improve source heading buttons, layout and interactions in the "
+          (:nxref :class-name 'prompt-buffer) ".")
+     (:li "Add checkboxes for suggestions within the "
+          (:nxref :class-name 'prompt-buffer) ".")))
+  (:nsection :title "Bug fixes"
+    (:ul
+     (:li "Fix command "
+          (:nxref :command 'nyxt/mode/annotate:show-annotations-for-current-url) ".")
+     (:li "Command " (:code "nyxt/renderer/gtk:make-buffer-with-context")
+          " now lists previously defined contexts.")
+     (:li "Improve architecture of " (:nxref :class-name 'nyxt/mode/hint:hint-mode)
+          " as to ensure that hints are shown for arbitrary URLs." ))))
