@@ -24,13 +24,14 @@ in viewport only and they're followed when user input matches the hint string.")
    (style
     (theme:themed-css (theme *browser*)
       `(".nyxt-hint"
-        :background-color ,theme:background
+        :background-color ,(cl-colors2:print-hex theme:background- :alpha 0.925)
         :color ,theme:on-background
         :font-family "monospace,monospace"
+        :font-size ".85rem"
         :padding "0px 0.3em"
-        :border-color ,theme:primary
-        :border-radius "0.3em"
-        :border-width "0.2em"
+        :border-color ,(cl-colors2:print-hex theme:primary- :alpha 0.80)
+        :border-radius "3px"
+        :border-width "2px"
         :border-style "solid"
         :z-index #.(1- (expt 2 31)))
       `(".nyxt-hint.nyxt-mark-hint"
@@ -107,6 +108,9 @@ A positive value shifts to the bottom.")
        "g f" 'follow-hint-nosave-buffer
        "g F" 'follow-hint-nosave-buffer-focus)))))
 
+(define-configuration document-buffer
+  ((default-modes (cons 'hint-mode %slot-value%))))
+
 (define-parenscript-async hint-elements (hints nyxt-identifiers)
   (defun create-hint-overlay (original-element hint)
     "Create a DOM element to be used as a hint."
@@ -130,7 +134,7 @@ A positive value shifts to the bottom.")
             (ps:@ element text-content) hint)
       element))
 
-  (let ((fragment (ps:chain document (create-document-fragment)))
+  (let ((hints-parent (ps:chain document (create-element "div")))
         (hints (ps:lisp (list 'quote hints)))
         (nyxt-identifiers (ps:lisp (list 'quote nyxt-identifiers))))
     (dotimes (i (length hints))
@@ -138,10 +142,12 @@ A positive value shifts to the bottom.")
              (nyxt-identifier (aref nyxt-identifiers i))
              (element (nyxt/ps:rqs-nyxt-id document nyxt-identifier)))
         (ps:chain element (set-attribute "nyxt-hint" hint))
-        (ps:chain fragment (append-child (create-hint-overlay element hint)))
+        (ps:chain hints-parent (append-child (create-hint-overlay element hint)))
         (when (ps:lisp (show-hint-scope-p (find-submode 'hint-mode)))
           (ps:chain element class-list (add "nyxt-element-hint")))))
-    (ps:chain document body (append-child fragment))
+    (setf (ps:@ hints-parent id) "nyxt-hints"
+          (ps:@ hints-parent style) "all: unset !important;")
+    (ps:chain document body parent-node (insert-before hints-parent (ps:@ document body next-sibling)))
     ;; Returning fragment makes WebKit choke.
     nil))
 
@@ -199,8 +205,9 @@ A positive value shifts to the bottom.")
                                             hintable-elements)))))
 
 (define-parenscript-async remove-hint-elements ()
-  (ps:dolist (element (nyxt/ps:rqsa document ":not(.nyxt-search-node) > .nyxt-hint"))
-    (ps:chain element (remove)))
+  (ps:let ((hints-parent (nyxt/ps:qs-id document "nyxt-hints")))
+    (ps:when hints-parent
+      (ps:chain hints-parent (remove))))
   (when (ps:lisp (show-hint-scope-p (find-submode 'hint-mode)))
     (ps:dolist (element (nyxt/ps:rqsa document ".nyxt-element-hint"))
       (ps:chain element class-list (remove "nyxt-element-hint")))))
